WheelSlot = class(Turbine.UI.Lotro.Quickslot);

function WheelSlot:Constructor(id, window)
  Turbine.UI.Lotro.Quickslot.Constructor(self);
  self.id = id;
  self:SetParent(window);
  self:getData();
  self:SetPosition(0, dragHeight);
  self:SetSize(quickSlotSize, quickSlotSize);
  self:SetAllowDrop(true);
  self:SetOpacity(1);
  self:SetVisible(true);
  self.updateShortcut = true;
  self:redrawShortcut();
  self:output("Slot Created");

  self.ShortcutChanged = function(sender, args)
    if (self.updateShortcut) then
      self:SetBackColor(invisible);
      local shortcut = convertFromShortcut(self:GetShortcut());
      table.insert(data.wheels[self.id].lists[self.list], shortcut);
      self.positions[self.list] = table.getn(data.wheels[self.id].lists[self.list]);
      saveData();
      self:output("|Type=" .. shortcut.Type .. "|Data=" .. shortcut.Data .. "|");
    end
  end

  self.MouseWheel = function(sender, args)
    self.positions[self.list] = self.positions[self.list] - args.Direction;
    if (self.positions[self.list] > table.getn(data.wheels[self.id].lists[self.list])) then
        self.positions[self.list] = 1;
    end
    if (self.positions[self.list] < 1) then
        self.positions[self.list] = table.getn(data.wheels[self.id].lists[self.list]);
    end
    if (self.positions[self.list] < 1) then
        self.positions[self.list] = 1;
    end
    self:redrawShortcut();
    self:output("Wheel |" .. self.positions[self.list] .. "|");
  end

  self.MouseClick = function(sender, args)
    if (args.Button == Turbine.UI.MouseButton.Right) then
      self.list = self.list + 1;
      if (self.list > 2) then
        self.list = 1;
      end
      self:redrawShortcut();
      self:output("Switching List |" .. self.list .. "|");
    end
  end

  self.MouseLeave = function(sender, args)
    if (
      (data.wheels[self.id].list ~= self.list) or
      (data.wheels[self.id].positions[1] ~= self.positions[1]) or
      (data.wheels[self.id].positions[2] ~= self.positions[2])
    ) then
      data.wheels[self.id].list = self.list;
      data.wheels[self.id].positions[1] = self.positions[1];
      data.wheels[self.id].positions[2] = self.positions[2];
      saveData();
      self:output("Saving Changes");
    end
  end
end

function WheelSlot:output(message)
  verboseOutput(self.id .. " - " .. message);
end

function WheelSlot:redrawShortcut()
  self.updateShortcut = false;
  if (data.wheels[self.id].lists[self.list][self.positions[self.list]]) then
    self:SetShortcut(
      convertToShortcut(data.wheels[self.id].lists[self.list][self.positions[self.list]])
    );
    self:SetBackColor(invisible);
  else
    self:SetShortcut(nil);
    self:SetBackColor(white);
  end
  self.updateShortcut = true;
end

function WheelSlot:getData()
  if (not data.wheels[self.id].list) then
    data.wheels[self.id].list = 1;
  end
  if (type(data.wheels[self.id].positions) ~= "table") then
    data.wheels[self.id].positions = {};
  end
  if (not data.wheels[self.id].positions[1]) then
    data.wheels[self.id].positions[1] = 1;
  end
  if (not data.wheels[self.id].positions[2]) then
    data.wheels[self.id].positions[2] = 1;
  end
  if (type(data.wheels[self.id].lists) ~= "table") then
    data.wheels[self.id].lists = {};
  end
  if (type(data.wheels[self.id].lists[1]) ~= "table") then
    data.wheels[self.id].lists[1] = {};
  end
  if (type(data.wheels[self.id].lists[2]) ~= "table") then
    data.wheels[self.id].lists[2] = {};
  end
  self.list = data.wheels[self.id].list;
  self.positions = {};
  self.positions[1] = data.wheels[self.id].positions[1];
  self.positions[2] = data.wheels[self.id].positions[2];
end
